@@ -2,16 +2,16 @@
 The ibidas module contains all main functions for working with ibidas objects.
 """
 
-__all__ = ["Rep","Read","Connect","_",
+__all__ = ["Rep","Read","Connect","_","CyNetwork",
            "Array","Tuple","Combine","HArray",
-           "Stack",
+           "Stack","Intersect","Union","Except","Difference",
            "Pos","Argsort",
            "Any","All",
            "Max","Min",
            "Argmin","Argmax",
            "Mean","Median",
            "Sum",
-           "Count",
+           "Count","Match",
            "Broadcast","CreateType",
            "newdim","Missing",
            "Corr","In","Contains",
@@ -24,24 +24,29 @@ from utils import delay_import
 from utils.util import save_rep as Save, load_rep as Load
 from utils.context import _
 from utils.missing import Missing
-from utils.infix import Infix,RevInfix
+from utils.infix import Infix
 from itypes import createType as CreateType
 from wrappers.wrapper_py import Rep
-from wrappers.wrapper_tsv import TSVRepresentor
-from wrappers.wrapper_sql import open_db
 from representor import newdim
 import repops_dim 
-from repops_multi import Broadcast, Combine, Sort, Stack
+from repops_multi import Broadcast, Combine, Sort
 import repops_slice 
 import repops_funcs
 from download_cache import DownloadCache
 from pre import predefined_sources as Get
+from cytoscape import CyNetwork
 from server import Serve
 from constants import *
 
 Fetch = DownloadCache()
 In = Infix(repops_funcs.Within)
 Contains = Infix(repops_funcs.Contains)
+Match = Infix(repops_multi.Match)
+Stack = Infix(repops_multi.Stack)
+Intersect = Infix(repops_multi.Intersect)
+Union = Infix(repops_multi.Union)
+Except = Infix(repops_multi.Except)
+Difference = Infix(repops_multi.Difference)
 
 Pos = repops.delayable(default_params="#")(repops_funcs.Pos)
 Argsort = repops.delayable()(repops_funcs.Argsort)
@@ -69,6 +74,7 @@ def Read(url, **kwargs):
     format = kwargs.pop('format','tsv')
 
     if(format == 'tsv'):
+        from wrappers.wrapper_tsv import TSVRepresentor
         return TSVRepresentor(url, **kwargs) 
     else:
         raise RuntimeError("Unknown format specified")
@@ -76,6 +82,7 @@ def Read(url, **kwargs):
 def Connect(url, **kwargs):
     format = kwargs.pop('format','db')
     if(format == "db"):
+        from wrappers.wrapper_sql import open_db
         return open_db(url, **kwargs)
     else:
         raise RuntimeError("Unknown format specified")
