@@ -121,7 +121,7 @@ class DimPath(tuple):
 
         res = self[:max(pos,0)] + DimPath(*ndims)
         if(not subtype is None):
-            subtype = subtype._removeDepDim(dimdepth=len(self)-pos, elem_specifier=elem_specifier)
+            subtype = subtype._removeDepDim(pos=pos - len(self), elem_specifier=elem_specifier)
             return (res,subtype)
         else:
             return res#}}}
@@ -140,21 +140,26 @@ class DimPath(tuple):
             res = DimPath(*ndims)
 
         if(not subtype is None):     
-            subtype = subtype._updateDepDim(dimdepth=len(self)-pos, ndim=ndim)
+            subtype = subtype._updateDepDim(pos=pos - len(self), ndim=ndim)
             return (res,subtype)
         else:
             return res#}}}
     
     def insertDim(self, pos, ndim, subtype=None):#{{{
         ndims = []
+        if(pos < 0):
+            refpos = pos;
+        else:
+            refpos = pos - 1;
+
         for p in xrange(max(pos,0), len(self)):
-            ndims.append(self[p].insertDepDim(p - pos - 1, ndim))
+            ndims.append(self[p].insertDepDim(p - refpos - 1, ndim))
         if pos >= 0:
             res = self[:pos] + (ndim,) + DimPath(*ndims)
         else:
             res = DimPath(*ndims)
         if(not subtype is None):
-            subtype = subtype._insertDepDim(dimdepth=len(self) - pos + 1, ndim=ndim)
+            subtype = subtype._insertDepDim(pos=refpos - len(self), ndim=ndim)
             return (res,subtype)
         else:
             return res#}}}
@@ -270,13 +275,15 @@ def commonDimPath(dimpaths):#{{{
         pos += 1
     return list(dimpaths)[0][:pos]#}}}
 
-def uniqueDimPath(dimpaths,only_complete=True):#{{{
+def uniqueDimPath(dimpaths,only_unique=True):#{{{
     """Returns unique dim path, i.e. at each nesting level determines
     if dim is unique and adds it to path. """
 
+    if not dimpaths:
+        return []
     fdims = set(dimpaths)
 
-    if(len(fdims) <= 1):
+    if(len(fdims) == 1):
         path = fdims.pop()
     else:
         path = []
@@ -284,6 +291,8 @@ def uniqueDimPath(dimpaths,only_complete=True):#{{{
             dimset = set([elem for elem in elems if not elem is None])
             if(len(dimset) == 1):
                 path.append(dimset.pop())
+            elif only_unique:
+                return path
             else:
                 path.append(dimset)
     return path#}}}
@@ -361,7 +370,7 @@ def planBroadcastMatchDim(paths):#{{{
             newnode = False
 
             #new wildcard dim?
-            if(dim.shape == 1 and dim.has_missing is False and not dimid in wildcard_links):
+            if(False and dim.shape == 1 and dim.has_missing is False and not dimid in wildcard_links):
                 odimid = dimid
                 dimids = graph.getParents(lastid)
                 if(dimids):
