@@ -1,8 +1,16 @@
+from ibidas.utils import util
 _delay_import_(globals(),"ibidas","*")
 
 class Pre(object):
-    def register(self, func):
-        setattr(self,func.__name__, func)
+    def register(self, func, name=None, category=None):
+        if category:
+            if not category in self.__dict__:
+                self.__dict__[category] = Pre()
+            self.__dict__[category].register(func, name)
+        else:
+            if(name is None):
+                name = func.__name__
+            setattr(self,name,func)
 predefined_sources = Pre()
 
 
@@ -23,7 +31,7 @@ def yeast_feats():
     res = res.To(_.start, _.stop, Do=_.Cast("int$"))
     res = res.To(_.genetic_pos,   Do=_.Cast("real64$"))
     return res.Copy()
-predefined_sources.register(yeast_feats)  
+predefined_sources.register(yeast_feats,name="genomic_feats",category="yeast")  
 
 
 def yeast_aliases(feats):
@@ -39,7 +47,23 @@ def yeast_aliases(feats):
     res = res%"feat_aliases"
     res = res[_.alias != ""]
     return res.Unique().Copy()
-predefined_sources.register(yeast_aliases)  
+predefined_sources.register(yeast_aliases,name="name_aliases",category="yeast")  
+
+
+def yeast_phosphosites():
+    url = "http://www.phosphogrid.org/downloads/phosphosites.txt"
+    rtype = """[phosphosites:*]<(orf_name=bytes, gene_name=bytes, phospho_site=bytes, site_evidence=bytes, 
+               site_evidence_pubmed=bytes, site_conditions=bytes, site_conditions_pubmed=bytes, site_functions=bytes, site_functions_pubmed=bytes, 
+               kinases_orfs=bytes, kinases_genes=bytes, kinases_evidence=bytes, kinases_evidence_pubmed=bytes, phosphatases_orfs=bytes, 
+               phosphatases_genes=bytes, phosphatases_evidence=bytes, phosphatases_evidence_pubmed=bytes, sequence=bytes, notes=bytes)"""
+    res = Read(Fetch(url),fieldnames=True,dtype=rtype)
+    splitfunc = lambda x: x.split("|")
+    res = res.To(_.site_evidence,  Do=_.Each(splitfunc, dtype="[site_evidences:~]<bytes").Elem()[_ != "-"])
+    res = res.To(_.site_evidence_pubmed,  Do=_.Each(splitfunc, dtype="[site_evidence_pubmeds:~]<bytes").Elem()[_ != "-"])
+    res = res.To(_.kinases_orfs,  Do=_.Each(splitfunc, dtype="[kinases:~]<bytes").Elem()[_ != "-"])
+    res = res.To(_.phosphatases_orfs,  Do=_.Each(splitfunc, dtype="[phosphatases:~]<bytes").Elem()[_ != "-"])
+    return res.Copy()
+predefined_sources.register(yeast_phosphosites,name="phosphosites",category="yeast")  
 
 def in_memory_db():
     """Returns an empty in memory database"""
@@ -52,7 +76,7 @@ def yeastract(url="http://www.yeastract.com/download/RegulationTwoColumnTable_Do
     rtype = "[tftargets:*]<(trans_factor=bytes, target=bytes)"
     res = Read(Fetch(url),dtype=rtype)
     return res.Copy()
-predefined_sources.register(yeastract)
+predefined_sources.register(yeastract,category="yeast")
 
 
 def string_interactions(dburl, species="Saccharomyces cerevisiae"):
@@ -69,11 +93,10 @@ def string_interactions(dburl, species="Saccharomyces cerevisiae"):
 
     """
     z = Connect(dburl)
-    pyeast = z.items.proteins 
-    inter  = z.items.species.Match(z.network.protein_protein_links)
+    inter  = z.items.species |Match| z.network.protein_protein_links
     inter  = inter[_.official_name == species]
-    inter  = inter.Match(pyeast//"left", _.protein_id_a, _.protein_id)
-    inter  = inter.Match(pyeast//"right",_.protein_id_b, _.protein_id)
+    inter  = inter |Match(_.protein_id_a, _.protein_id)| z.items.proteins//"left"
+    inter  = inter |Match(_.protein_id_b, _.protein_id)| z.items.proteins//"right"
     return   inter.Get(_.left.preferred_name/"left", 
                        _.right.preferred_name/"right", 
                        _.combined_score) % "interactions"
@@ -97,7 +120,7 @@ def omim_genemap():
     res = res.To(_.mim, Do=_.Cast("int"))
 
     return res.Without(_.f8, _.f12, _.disease1, _.disease2, _.disease3).Copy()
-predefined_sources.register(omim_genemap)
+predefined_sources.register(omim_genemap, category="human")
 
 def omim_disease_parse(x):
     x = x.replace('{','').replace('}','')
@@ -113,14 +136,41 @@ def go_annotations(dburl, genus="Saccharomyces", species="cerevisiae"):
        example url: "mysql://username:password@hostname:port/go
     """
     go = Connect(dburl)
-    g = go.species
-    g = g.Match(go.gene_product,     _.id,                   _.species_id)
-    g = g.Match(go.association,      _.gene_product.id,      _.gene_product_id)
-    g = g.Match(go.graph_path,       _.association.term_id,  _.term2_id)
-    g = g.Match(go.term//"annot",_.term1_id,             _.id)
-    g = g.Match(go.term//"rel",  _.relationship_type_id, _.id)
+    g = go.species |Match(_.id,                   _.species_id)|      go.gene_product
+    g = g          |Match(_.gene_product.id,      _.gene_product_id)| go.association
+    g = g          |Match(_.association.term_id,  _.term2_id)|        go.graph_path
+    g = g          |Match(_.term1_id,             _.id)|              go.term//"annot"
+    g = g          |Match(_.relationship_type_id, _.id)|              go.term//"rel"
     g = g[(_.genus==genus) & (_.species == species)]
     return g.Get(_.symbol, _.annot.name/"annotation", _.rel.name/"relation_type", _.distance)%"annotations"
 predefined_sources.register(go_annotations)
 
-    
+
+########################### #KEGG ######################################
+@util.memoized
+def kegg():
+    from SOAPpy import WSDL
+    wsdl = 'http://soap.genome.jp/KEGG.wsdl';
+    serv = WSDL.Proxy(wsdl)
+    return serv
+
+def get_kegg_organisms():
+    serv = kegg()
+    return Rep(serv.list_organisms())
+predefined_sources.register(get_kegg_organisms,name="organisms", category="kegg")
+
+def get_kegg_pathways(org):
+    serv = kegg()
+    return Rep(serv.list_pathways(org))
+predefined_sources.register(get_kegg_pathways,name="pathways", category="kegg")
+
+def get_kegg_pathway(pathway):
+    serv = kegg()
+    relations = Rep(serv.get_element_relations_by_pathway(pathway))
+    elements = Rep(serv.get_elements_by_pathway(pathway))
+    return Combine(elements,relations)
+
+
+    return Rep(serv.list_pathways(org))
+predefined_sources.register(get_kegg_pathways,name="pathways", category="kegg")
+
