@@ -257,6 +257,10 @@ class Representor(Node):
                     tuple([slice.name for slice in self._slices]))
     Type=property(fget=getType)
 
+    def getSlices(self):
+        return list(self._slices)
+    Slices=property(fget=getSlices)
+
     def getDepth(self):
         """Returns max dimension depth (number of dimensins) of
            slices in this representor. 
@@ -444,7 +448,7 @@ class Representor(Node):
     
     # or operator ( | )
     def __or__(self, other):
-        if(isinstance(other, (context.Context, infix.Infix, infix.RevInfix))):
+        if(isinstance(other, (context.Context, infix.Infix))):
             return other.__ror__(self)
         return repops_funcs.Or(self, other)
 
@@ -510,6 +514,8 @@ class Representor(Node):
         return repops_funcs.Negative(self)
 
     def __nonzero__(self):
+        self._checkState(filter=RS_SLICES_KNOWN)
+
         if(len(self._slices) != 1):
             raise RuntimeError, "Cannot determine True/False status of a multi-slice representor"
 
@@ -719,6 +725,10 @@ class Representor(Node):
         """Packages dimension into array type"""
         return repops_dim.Array(self, tolevel = tolevel)
 
+    def Level(self, tolevel):
+        """Bring all slices to same dimension height throug packing and broadcasting"""
+        return repops_dim.Level(self, tolevel)
+
     def Tuple(self):
         """Combines slices into a tuple type"""
         return repops_slice.Tuple(self)
