@@ -187,8 +187,6 @@ def transpose_table(table):
         cols.append([row[col] for row in table])
     return cols
         
-
-
 def contained_in(inner_tuple, outer_tuple):
     pos = 0
     linner_tuple = len(inner_tuple)
@@ -301,3 +299,39 @@ def format_runtime(rtime):
     return u"%.*g %s" % (3, rtime * scaling[order],units[order])
 
 
+def check_module(modulename):
+    try:
+        __import__(modulename)
+        return True
+    except ImportError:
+        return False
+
+#from: http://wiki.python.org/moin/PythonDecoratorLibrary#Memoize
+class memoized(object):
+   """Decorator that caches a function's return value each time it is called.
+   If called later with the same arguments, the cached value is returned, and
+   not re-evaluated.
+   """
+   def __init__(self, func):
+      self.func = func
+      self.cache = {}
+   def __call__(self, *args):
+       try:
+          return self.cache[args]
+       except KeyError:
+          value = self.func(*args)
+          self.cache[args] = value
+          return value
+       except TypeError:
+          # uncachable -- for instance, passing a list as an argument.
+          # Better to not cache than to blow up entirely.
+          return self.func(*args)
+
+   def __repr__(self):
+       """Return the function's docstring."""
+       return self.func.__doc__
+
+   def __get__(self, obj, objtype):
+       """Support instance methods."""
+       return functools.partial(self.__call__, obj)
+
