@@ -517,6 +517,14 @@ class PyExec(VisitorFactory(prefixes=("visit",), flags=NF_ELSE),
         func = stringset_to_array
         dtype = node.type.toNumpy()
         return slice.data.mapseq(func, dtype=dtype, res_type=node.type)
+    
+    
+    def castto_bytes(self, castname, node, slice):
+        if(node.type.has_missing):
+            func = any_tobytes_missing
+        else:
+            func = any_tobytes
+        return slice.data.mapseq(func, res_type=node.type)
 
     def caststring_to_real(self, castname, node, slice):
         if(node.type.has_missing):
@@ -805,11 +813,17 @@ def speedfilter(seqs,has_missing, ctype):
                 res = cutils.darray(res,object)
         else:
             if(constraint is Missing):
-                return Missing
+                res = Missing
             else:
-                return data[constraint]
+                try:
+                    res = data[constraint]
+                except Exception:
+                    res = cutils.darray(data)[constraint]
     else:
-        res = data[constraint]
+        try:
+            res = data[constraint]
+        except Exception:
+            res = cutils.darray(data)[constraint]
     return res
 
 def ensure_fixeddims(seqs,packdepth,dtype):
@@ -949,6 +963,20 @@ def stringset_to_array(seq, dtype):
     return cutils.darray(res)
 
 
+def any_tobytes_missing(seq):
+    res = []
+    for elem in seq:
+        if elem is Missing:
+            res.append(Missing)
+        else:
+            res.append(str(elem))
+    return cutils.darray(res)
+
+def any_tobytes(seq):
+    res = [str(elem) for elem in seq]
+    return cutils.darray(res)
+
+
 def string_to_int_missing(seq, dtype):
     res = []
     for elem in seq:
